@@ -11,6 +11,10 @@
 #include <QDir>
 #include <QDebug>
 #include <QDateTime>
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(logApp)
+
 #define MAINWINDOW_HEIGHT_NAME "logMainWindowHeightName"
 #define MAINWINDOW_WIDTH_NAME "logMainWindowWidthName"
 
@@ -31,10 +35,11 @@ LogSettings::LogSettings(QObject *parent)
       m_configPath(""),
       m_logDirPath("")
 {
-    qDebug() << "Initializing log settings, config path:" << Utils::getConfigPath();
+    qCDebug(logApp) << "Initializing log settings, config path:" << Utils::getConfigPath();
 
     QDir infoPath(Utils::getConfigPath());
     if (!infoPath.exists()) {
+        qCDebug(logApp) << "Info path does not exist, creating it";
         infoPath.mkpath(Utils::getConfigPath());
     }
 
@@ -51,24 +56,24 @@ LogSettings::LogSettings(QObject *parent)
  */
 QSize LogSettings::getConfigWinSize()
 {
-    qDebug() << "Getting configured window size from:" << m_configPath;
+    qCDebug(logApp) << "Getting configured window size";
 
     QVariant tempHeight = m_winInfoConfig->value(MAINWINDOW_HEIGHT_NAME);
     QVariant tempWidth = m_winInfoConfig->value(MAINWINDOW_WIDTH_NAME);
     int winHeight = MAINWINDOW_HEIGHT;
     int winWidth = MAINWINDOW_WIDTH;
     if (tempHeight.isValid()) {
-
+        qCDebug(logApp) << "tempHeight is valid";
         winHeight = tempHeight.toInt();
         winHeight = winHeight > MAINWINDOW_HEIGHT ? winHeight : MAINWINDOW_HEIGHT;
     }
     if (tempHeight.isValid()) {
-
+        qCDebug(logApp) << "tempWidth is valid";
         winWidth = tempWidth.toInt();
         winWidth = winWidth > MAINWINDOW_WIDTH ? winWidth : MAINWINDOW_WIDTH;
     }
 
-    qDebug() << "Returning window size:" << QSize(winWidth, winHeight);
+    qCDebug(logApp) << "Returning window size:" << QSize(winWidth, winHeight);
     return QSize(winWidth, winHeight);
 }
 
@@ -79,7 +84,7 @@ QSize LogSettings::getConfigWinSize()
  */
 void LogSettings::saveConfigWinSize(int w, int h)
 {
-    qDebug() << "Saving window size:" << w << "x" << h << "to:" << m_configPath;
+    qCDebug(logApp) << "Saving window size:" << w << "x" << h;
 
     int winWidth = w > MAINWINDOW_WIDTH ? w : MAINWINDOW_WIDTH;
     int winHeight = h > MAINWINDOW_HEIGHT ? h : MAINWINDOW_HEIGHT;
@@ -90,7 +95,7 @@ void LogSettings::saveConfigWinSize(int w, int h)
 
 QMap<QString, QStringList> LogSettings::loadAuditMap()
 {
-    qDebug() << "Loading audit rules from:" << AUDIT_CONFIG_PATH;
+    qCDebug(logApp) << "Loading audit rules from:" << AUDIT_CONFIG_PATH;
 
     QMap<QString, QStringList> auditType2EventType;
     QSettings auditConfig(AUDIT_CONFIG_PATH, QSettings::IniFormat);
@@ -101,6 +106,6 @@ QMap<QString, QStringList> LogSettings::loadAuditMap()
         auditType2EventType.insert(auditType, strList);
     }
 
-    qDebug() << "Loaded" << auditType2EventType.size() << "audit rules";
+    qCDebug(logApp) << "Loaded" << auditType2EventType.size() << "audit rules";
     return auditType2EventType;
 }
