@@ -1,27 +1,35 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="cs">
 <context>
     <name>Action</name>
     <message>
+        <location filename="../application/displaycontent.cpp" line="188"/>
         <source>Display in file manager</source>
         <translation>Zobrazit ve správci souborů</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="489"/>
         <source>Clear log</source>
         <translation>Vyčistit záznam událostí (log)</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="189"/>
         <source>Refresh</source>
         <translation>Načíst znovu</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="539"/>
         <source>Are you sure you want to clear the log?</source>
         <translation>Opravdu chcete záznam událostí vyčistit?</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="540"/>
         <source>Cancel</source>
         <translation>Storno</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="541"/>
         <source>Confirm</source>
         <translation>Potvrdit</translation>
     </message>
@@ -29,30 +37,37 @@
 <context>
     <name>Button</name>
     <message>
+        <location filename="../application/filtercontent.cpp" line="80"/>
         <source>All</source>
         <translation>Vše</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="83"/>
         <source>Today</source>
         <translation>Dnes</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="86"/>
         <source>3 days</source>
         <translation>3 dny</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="89"/>
         <source>1 week</source>
         <translation>1 týden</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="92"/>
         <source>1 month</source>
         <translation>1 měsíc</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="95"/>
         <source>3 months</source>
         <translation>3 měsíce</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="224"/>
         <source>Export</source>
         <comment>button</comment>
         <translation>Export</translation>
@@ -61,82 +76,102 @@
 <context>
     <name>ComboBox</name>
     <message>
+        <location filename="../application/filtercontent.cpp" line="120"/>
         <source>All</source>
         <translation>Vše</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="121"/>
         <source>Emergency</source>
         <translation>Nouzové</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="122"/>
         <source>Alert</source>
         <translation>Výstraha</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="123"/>
         <source>Critical</source>
         <translation>Kritické</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="124"/>
         <source>Error</source>
         <translation>Chyba</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="125"/>
         <source>Warning</source>
         <translation>Varování</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="126"/>
         <source>Notice</source>
         <translation>Upozornění</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="127"/>
         <source>Info</source>
         <translation>Pro informaci</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="128"/>
         <source>Debug</source>
         <translation>Ladění</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="198"/>
         <source>Login</source>
         <translation>Přihlášení</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="199"/>
         <source>Boot</source>
         <translation>Start systému</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="200"/>
         <source>Shutdown</source>
         <translation>Vypínání</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="142"/>
         <source>Super critical</source>
         <translation>Super kritické</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="148"/>
         <source>Trace</source>
         <translation>Trace</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="212"/>
         <source>Identity authentication</source>
         <translation>Ověření identity</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="213"/>
         <source>Discretionary Access Control</source>
         <translation>Rozvahové/posudkové řízení přístupu</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="214"/>
         <source>Mandatory access control</source>
         <translation>Mandatorní řízení přístupu</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="215"/>
         <source>Remote</source>
         <translation>Vzdálené</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="216"/>
         <source>Document audit</source>
         <translation>Audit dokumentu</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="217"/>
         <source>Other</source>
         <translation>Ostatní</translation>
     </message>
@@ -144,10 +179,12 @@
 <context>
     <name>DisplayContent</name>
     <message>
+        <location filename="../application/displaycontent.cpp" line="1800"/>
         <source>zip(*.zip)</source>
-        <translation type="unfinished"/>
+        <translation>zipping (*.zip)</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="1794"/>
         <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
         <translation>TEXT (*.txt);; Doc (*.doc);; XLS (*.xls);; HTML (*.html)</translation>
     </message>
@@ -155,10 +192,12 @@
 <context>
     <name>ExportDlg</name>
     <message>
+        <location filename="../application/exportprogressdlg.cpp" line="35"/>
         <source>Exporting...</source>
         <translation>Exportování…</translation>
     </message>
     <message>
+        <location filename="../application/exportprogressdlg.cpp" line="58"/>
         <source>Cancel</source>
         <translation>Storno</translation>
     </message>
@@ -166,21 +205,25 @@
 <context>
     <name>ExportMessage</name>
     <message>
+        <location filename="../application/displaycontent.cpp" line="3257"/>
         <source>Export successful</source>
         <translation>Export úspěšný</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="3260"/>
         <source>Export failed</source>
         <translation>Export se nezdařil</translation>
     </message>
     <message>
+        <location filename="../application/logbackend.cpp" line="1763"/>
         <source>The export directory is not available. Please choose another directory for the export operation.</source>
-        <translation type="unfinished"/>
+        <translation>Exportní složka není dostupná. Prosím, vyberte jinou složku pro exportní operaci.</translation>
     </message>
 </context>
 <context>
     <name>File</name>
     <message>
+        <location filename="../application/displaycontent.cpp" line="1792"/>
         <source>Export File</source>
         <translation>Exportovat soubor</translation>
     </message>
@@ -188,101 +231,125 @@
 <context>
     <name>Label</name>
     <message>
+        <location filename="../application/filtercontent.cpp" line="76"/>
         <source>Period:</source>
         <translation>Období:</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="114"/>
         <source>Level:  </source>
         <translation>Úroveň podrobností:  </translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="180"/>
         <source>Status:</source>
         <translation>Stav:</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="193"/>
         <source>Event Type:</source>
         <translation>Typ události:</translation>
     </message>
     <message>
+        <location filename="../application/logdetailinfowidget.cpp" line="132"/>
         <source>User:</source>
         <translation>Uživatel:</translation>
     </message>
     <message>
+        <location filename="../application/logdetailinfowidget.cpp" line="134"/>
         <source>PID:</source>
         <translation>Identif. procesu:</translation>
     </message>
     <message>
+        <location filename="../application/logdetailinfowidget.cpp" line="138"/>
         <source>Action:</source>
         <translation>Akce:</translation>
     </message>
     <message>
+        <location filename="../application/logdetailinfowidget.cpp" line="143"/>
         <source>Username:</source>
         <translation>Uživatelské jméno:</translation>
     </message>
     <message>
+        <location filename="../application/logdetailinfowidget.cpp" line="469"/>
         <source>Boot record</source>
         <translation>Záznam události ze startu systému</translation>
     </message>
     <message>
+        <location filename="../application/logdetailinfowidget.cpp" line="471"/>
         <source>Shutdown record</source>
         <translation>Záznam událostí z vypínání</translation>
     </message>
     <message>
+        <location filename="../application/logdetailinfowidget.cpp" line="474"/>
         <source>Login record</source>
         <translation>Záznam událostí z přihlašování</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="208"/>
         <source>Audit Type:</source>
         <translation>Typ auditu:</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="155"/>
         <source>Application:</source>
-        <translation type="unfinished"/>
+        <translation>Aplikace:</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="167"/>
         <source>Submodule:</source>
-        <translation type="unfinished"/>
+        <translation>Podmodul:</translation>
     </message>
 </context>
 <context>
     <name>Level</name>
     <message>
+        <location filename="../application/displaycontent.cpp" line="201"/>
         <source>Warning</source>
         <translation>Varování</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="202"/>
         <source>Debug</source>
         <translation>Ladění</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="203"/>
         <source>Info</source>
         <translation>Pro informaci</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="204"/>
         <source>Error</source>
         <translation>Chyba</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="208"/>
         <source>Emergency</source>
         <translation>Nouzové</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="209"/>
         <source>Alert</source>
         <translation>Výstraha</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="210"/>
         <source>Critical</source>
         <translation>Kritická</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="213"/>
         <source>Notice</source>
         <translation>Upozornění</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="220"/>
         <source>Trace</source>
         <translation>Trace</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="226"/>
         <source>Super critical</source>
         <translation>Super kritické</translation>
     </message>
@@ -290,6 +357,7 @@
 <context>
     <name>LogAuthThread</name>
     <message>
+        <location filename="../application/logauththread.cpp" line="529"/>
         <source>Log file is empty</source>
         <translation>Soubor se záznamem událostí je prázdný</translation>
     </message>
@@ -297,10 +365,12 @@
 <context>
     <name>Main</name>
     <message>
+        <location filename="../application/main.cpp" line="329"/>
         <source>Log Viewer</source>
         <translation>Prohlížeč záznamů událostí</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="332"/>
         <source>Log Viewer is a useful tool for viewing system logs.</source>
         <translation>Prohlížeč záznamů událostí je užitečným nástrojem pro prohlížení záznamů událostí v systému.</translation>
     </message>
@@ -308,10 +378,12 @@
 <context>
     <name>SearchBar</name>
     <message>
+        <location filename="../application/displaycontent.cpp" line="120"/>
         <source>No search results</source>
         <translation>Nic nenalezeno</translation>
     </message>
     <message>
+        <location filename="../application/logcollectormain.cpp" line="109"/>
         <source>Search</source>
         <translation>Hledat</translation>
     </message>
@@ -319,109 +391,135 @@
 <context>
     <name>Table</name>
     <message>
+        <location filename="../application/displaycontent.cpp" line="563"/>
         <source>Level</source>
         <translation>Úroveň podrobností</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="564"/>
         <source>Process</source>
         <translation>Proces</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="565"/>
         <source>Date and Time</source>
         <translation>Datum a čas</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="566"/>
         <source>Info</source>
         <translation>Pro informaci</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="567"/>
         <source>User</source>
         <translation>Uživatel</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="568"/>
         <source>PID</source>
         <translation>Identif. procesu (PID):</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="953"/>
         <source>Source</source>
         <translation>Zdroj</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="669"/>
         <source>Action</source>
         <translation>Akce</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="3374"/>
         <source>Status</source>
         <translation>Stav</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="1140"/>
         <source>Event Type</source>
         <translation>Typ události</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="1141"/>
         <source>Username</source>
         <translation>Uživatelské jméno</translation>
     </message>
     <message>
+        <location filename="../application/logexportthread.cpp" line="897"/>
         <source>Level:</source>
         <translation>Úroveň:</translation>
     </message>
     <message>
+        <location filename="../application/logexportthread.cpp" line="898"/>
         <source>Process:</source>
         <translation>Proces:</translation>
     </message>
     <message>
+        <location filename="../application/logexportthread.cpp" line="899"/>
         <source>Date and Time:</source>
         <translation>Datum a čas:</translation>
     </message>
     <message>
+        <location filename="../application/logexportthread.cpp" line="901"/>
         <source>Info:</source>
         <translation>Informace:</translation>
     </message>
     <message>
+        <location filename="../application/logexportthread.cpp" line="902"/>
         <source>Null</source>
         <translation>Prázdné</translation>
     </message>
     <message>
+        <location filename="../application/logexportthread.cpp" line="906"/>
         <source>User:</source>
         <translation>Uživatel:</translation>
     </message>
     <message>
+        <location filename="../application/logexportthread.cpp" line="907"/>
         <source>PID:</source>
         <translation>Identif. procesu:</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="3532"/>
         <source>File Name</source>
         <translation>Název souboru</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="3533"/>
         <source>Time Modified</source>
         <translation>Okamžik změny</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="3741"/>
         <source>SIG</source>
-        <translation type="unfinished"/>
+        <translation>SIG</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="3745"/>
         <source>EXE</source>
-        <translation type="unfinished"/>
+        <translation>EXE</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="3743"/>
         <source>Core File</source>
-        <translation type="unfinished"/>
+        <translation>Soubor jádra</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="3744"/>
         <source>User Name </source>
-        <translation type="unfinished"/>
+        <translation>Uživatelské jméno </translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="1009"/>
         <source>Offset</source>
-        <translation type="unfinished"/>
+        <translation>Offset</translation>
     </message>
 </context>
 <context>
     <name>Tbble</name>
     <message>
+        <location filename="../application/displaycontent.cpp" line="1142"/>
         <source>Date and Time</source>
         <translation>Datum a čas</translation>
     </message>
@@ -429,189 +527,233 @@
 <context>
     <name>Tree</name>
     <message>
+        <location filename="../application/loglistview.cpp" line="171"/>
         <source>System Log</source>
         <translation>Záznam událostí v systému</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="182"/>
         <source>Kernel Log</source>
         <translation>Události v jádru systému</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="203"/>
         <source>Boot Log</source>
         <translation>Záznam událostí ze startu systému</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="232"/>
         <source>dpkg Log</source>
         <translation>Události v systému správy balíčků</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="244"/>
         <source>Kwin Log</source>
         <translation>Záznam událostí v Kwin</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="253"/>
         <source>Xorg Log</source>
         <translation>Události v infrastruktuře pro zobrazování (Xorg)</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="265"/>
         <source>Application Log</source>
         <translation>Záznam událostí v aplikacích</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="290"/>
         <source>Boot-Shutdown Event</source>
         <translation>Událost při startu/vypínání systému</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="222"/>
         <source>dnf Log</source>
         <translation>záznam událostí v dnf</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="303"/>
         <source>Other Log</source>
         <translation>Jiný záznam</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="339"/>
         <source>Custom Log</source>
         <translation>Uživatelsky určený záznam událostí</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="319"/>
         <source>Audit Log</source>
         <translation>Auditní log</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="278"/>
         <source>Coredump Log</source>
-        <translation type="unfinished"/>
+        <translation>Log coredumpu</translation>
     </message>
 </context>
 <context>
     <name>Waring</name>
     <message>
+        <location filename="../application/displaycontent.cpp" line="133"/>
         <source>Unable to obtain crash information, please install systemd-coredump.</source>
-        <translation type="unfinished"/>
+        <translation>Nelze získat informace o havárii, nainstalujte prosím systemd-coredump.</translation>
     </message>
 </context>
 <context>
     <name>Warning</name>
     <message>
+        <location filename="../application/displaycontent.cpp" line="139"/>
         <source>You do not have permission to view it</source>
         <translation>Nemáte oprávnění k zobrazení</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="127"/>
         <source>Security level for the current system: high
  audit only administrators can view the audit log</source>
-        <translation type="unfinished"/>
+        <translation>Úroveň zabezpečení pro aktuální systém: vysoká
+ audit mohou zobrazit pouze administrátoři</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="3216"/>
         <source>Audit log is not exist.</source>
-        <translation type="unfinished"/>
+        <translation>Auditový log neexistuje.</translation>
     </message>
 </context>
 <context>
     <name>main</name>
     <message>
+        <location filename="../application/main.cpp" line="67"/>
         <source>Export logs to the specified path</source>
-        <translation type="unfinished"/>
+        <translation>Exportovat protokoly do zadaného cesty</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="67"/>
         <source>PATH</source>
-        <translation type="unfinished"/>
+        <translation>Cesta</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="68"/>
         <source>Export logs of specified types</source>
-        <translation type="unfinished"/>
+        <translation>Exportovat protokoly zadaných typů</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="68"/>
         <source>TYPE</source>
-        <translation type="unfinished"/>
+        <translation>Typ</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="69"/>
         <source>Export logs of specified self-developed applications</source>
-        <translation type="unfinished"/>
+        <translation>Exportovat protokoly zadaných vlastních aplikací</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="69"/>
         <source>SELF APPNAME</source>
-        <translation type="unfinished"/>
+        <translation>VLASTNÍ NÁZVÍ APLIKACE</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="70"/>
         <source>Export logs within a specified time period</source>
-        <translation type="unfinished"/>
+        <translation>Exportovat protokoly v zadaném časovém období</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="70"/>
         <source>PERIOD</source>
-        <translation type="unfinished"/>
+        <translation>Časové období</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="71"/>
         <source>Export logs within a specified debug level</source>
-        <translation type="unfinished"/>
+        <translation>Exportovat protokoly v zadané úrovni ladění</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="71"/>
         <source>LEVEL</source>
-        <translation type="unfinished"/>
+        <translation>Úroveň</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="72"/>
         <source>BOOT STATUS</source>
-        <translation type="unfinished"/>
+        <translation>STAV SPUSŤOVÁNÍ</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="72"/>
         <source>Export boot(no-klu) logs within a specified status</source>
-        <translation type="unfinished"/>
+        <translation>Exportovat protokoly spuštění (no-klu) v zadaném stavu</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="73"/>
         <source>Export boot-shutdown-event or audit logs within a specified event type</source>
-        <translation type="unfinished"/>
+        <translation>Exportovat protokoly spuštění, vypnutí nebo audit v zadaném typu události</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="73"/>
         <source>EVENT TYPE</source>
-        <translation type="unfinished"/>
+        <translation>Typ události</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="74"/>
         <source>Export logs based on keywords search results</source>
-        <translation type="unfinished"/>
+        <translation>Exportovat protokoly na základě výsledků vyhledávání klíčových slov</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="74"/>
         <source>KEY WORD</source>
-        <translation type="unfinished"/>
+        <translation>KLÍČOVÉ SLOVO</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="76"/>
         <source>Report coredump informations.</source>
-        <translation type="unfinished"/>
+        <translation>Zpráva o informacích coredumpu.</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="75"/>
         <source>Export logs based on app submodel</source>
-        <translation type="unfinished"/>
+        <translation>Exportovat protokoly podle podmodelu aplikace</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="75"/>
         <source>SUBMODULE</source>
-        <translation type="unfinished"/>
+        <translation>PODCHODNÍK</translation>
     </message>
 </context>
 <context>
     <name>titlebar</name>
     <message>
+        <location filename="../application/logcollectormain.cpp" line="202"/>
         <source>Refresh interval</source>
         <translation>Interval opakovaného načítání</translation>
     </message>
     <message>
+        <location filename="../application/logcollectormain.cpp" line="204"/>
         <source>10 sec</source>
         <translation>10 sekund</translation>
     </message>
     <message>
+        <location filename="../application/logcollectormain.cpp" line="205"/>
         <source>1 min</source>
         <translation>1 minuta</translation>
     </message>
     <message>
+        <location filename="../application/logcollectormain.cpp" line="206"/>
         <source>5 min</source>
         <translation>5 minut</translation>
     </message>
     <message>
+        <location filename="../application/logcollectormain.cpp" line="207"/>
         <source>No refresh</source>
         <translation>Nedonačítat</translation>
     </message>
     <message>
+        <location filename="../application/logcollectormain.cpp" line="234"/>
         <source>Export All</source>
         <translation>Exportovat vše</translation>
     </message>
     <message>
+        <location filename="../application/logcollectormain.cpp" line="240"/>
         <source>Refresh Now</source>
         <translation>Načíst znovu nyní</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
